## What

Brief description of changes.

## Why

Why is this change needed? Link to issue if applicable.

Closes #

## Type

- [ ] Bug fix
- [ ] New feature
- [ ] Refactor / cleanup
- [ ] Documentation
- [ ] Benchmark / test

## Checklist

- [ ] Tests added/updated
- [ ] `ruff check` passes
- [ ] `ruff format --check` passes
- [ ] `mypy turboquant/` passes
- [ ] `pytest tests/ -v` passes
- [ ] README updated (if new feature)
- [ ] PR targets `staging` (not `main`)
